@@ -1,6 +1,6 @@
 <?php
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -16,6 +16,7 @@
 
 /**
  * @var CView $this
+ * @var array $data
  */
 
 $form = (new CForm())
@@ -133,6 +134,7 @@ if ($data['is_item_testable']) {
 						SNMP_V2C => _('SNMPv2'),
 						SNMP_V3 => _('SNMPv3')
 					]))
+					->setAttribute('data-prevent-validation-on-change', 1)
 			))
 				->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID)
 				->addClass('js-popup-row-snmp-version'),
@@ -369,7 +371,8 @@ if (count($data['steps']) > 0) {
 		->setHeader([
 			'',
 			(new CColHeader(_('Name')))->addStyle('width: 100%;'),
-			(new CColHeader(_('Result')))->addClass(ZBX_STYLE_RIGHT)
+			(new CColHeader(_('Result')))->addClass(ZBX_STYLE_RIGHT),
+			''
 		]);
 
 	foreach ($data['steps'] as $i => $step) {
@@ -393,7 +396,16 @@ if (count($data['steps']) > 0) {
 				->addClass(ZBX_STYLE_WORDBREAK),
 			(new CCol())
 				->addClass(ZBX_STYLE_RIGHT)
-				->setId('preproc-test-step-'.$i.'-result')
+				->setId('preproc-test-step-'.$i.'-result'),
+			(new CCol(
+				(new CButton('copy_button-'.$i))
+					->setTitle(_('Copy to clipboard'))
+					->addClass(ZBX_ICON_COPY)
+					->addClass(ZBX_STYLE_BTN_GREY_ICON)
+					->addClass('js-copy-button')
+					->setAttribute('data-index', $i)
+					->addStyle('display: none')
+			))->addClass('result-copy')
 		]);
 	}
 
@@ -410,7 +422,9 @@ if (count($data['steps']) > 0) {
 if ($data['show_final_result']) {
 	$form_grid->addItem([
 		(new CLabel(_('Result')))->addClass('js-final-result'),
-		(new CFormField())->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID)
+		(new CFormField())
+			->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID)
+			->addClass('item-final-result')
 	]);
 }
 
